@@ -1,4 +1,3 @@
-#! /usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 from copy import deepcopy
@@ -234,7 +233,7 @@ def load(input_obj: str, check_dpg: bool = True) -> Type["TrxFile"]:
                 trx = load_from_directory(tmp_dir.name)
                 trx._uncompressed_folder_handle = tmp_dir
                 logging.info(
-                    "File was compressed, call the close() function before"
+                    "File was compressed, call the close() function before "
                     "exiting."
                 )
         else:
@@ -294,7 +293,7 @@ def load_from_zip(filename: str) -> Type["TrxFile"]:
             size = zip_info.file_size / dtype_size
 
             if len(zip_info.extra):
-                mem_adress += 4
+                mem_adress -= len(zip_info.extra)
 
             if size.is_integer():
                 files_pointer_size[elem_filename] = mem_adress, int(size)
@@ -541,13 +540,13 @@ def save(
             the ZipFile library
     """
     _, ext = os.path.splitext(filename)
-    if ext.lower() not in [".zip", ".trx", ""]:
+    if ext not in [".zip", ".trx", ""]:
         raise ValueError("Unsupported extension.")
 
     copy_trx = trx.deepcopy()
     copy_trx.resize()
     tmp_dir_name = copy_trx._uncompressed_folder_handle.name
-    if ext.lower() in [".zip", ".trx"]:
+    if ext in [".zip", ".trx"]:
         zip_from_folder(tmp_dir_name, filename, compression_standard)
     else:
         if os.path.isdir(filename):
